import React, { useState, useEffect } from 'react'
import { withClient, Client } from 'cozy-client'
import KonnectorStatusService from 'services/konnectorStatusService'
import KonnectorViewerCard from 'components/ContentComponents/KonnectorViewer/KonnectorViewerCard'
import IFluidConfig from 'services/IFluidConfig'

export interface KonnectorViewerProps {
  fluidConfig: IFluidConfig
  client: Client
  isParam: boolean
}

const KonnectorViewer: React.FC<KonnectorViewerProps> = ({
  fluidConfig,
  client,
  isParam = false,
}: KonnectorViewerProps) => {
  const [Konnectors, setKonnectors] = useState(null)
  const [Triggers, setTriggers] = useState(null)

  const setAllKonnectors = async () => {
    const kss = new KonnectorStatusService(client)
    const allKonnectors = await kss.getAllKonnectors()
    setKonnectors(allKonnectors)
    //console.log('All Konnectors',allKonnectors);
  }

  const setAllTriggers = async () => {
    const kss = new KonnectorStatusService(client)
    const allTriggers = await kss.getAllTriggers()
    setTriggers(allTriggers)
    //console.log('All Triggers',allTriggers)
  }

  const fetchKonnectorFromTrigger = trigger => {
    let konnectorName = ''
    try {
      konnectorName = trigger.message.konnector
    } catch (error) {
      return konnectorName
    }
    return konnectorName
  }

  const getLastTrigger = konnector => {
    if (!Triggers) return null
    const lastTrigger = Triggers.filter(
      trigger =>
        fetchKonnectorFromTrigger(trigger) === konnector.id.split('/').pop()
    )
      .sort((a, b) => (new Date(a) > new Date(b) ? 1 : -1))
      .shift()
    return lastTrigger
  }

  useEffect(() => {
    setAllKonnectors()
    setAllTriggers()
  }, [])

  return (
    <KonnectorViewerCard
      fluidConfig={fluidConfig}
      trigger={getLastTrigger(fluidConfig.konnectorConfig)}
      isParam={isParam}
    />
  )
}

export default withClient(KonnectorViewer)
